package com.zjsgfa.project.zjsgfa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zjsgfa.project.zjsgfa.mapper.SjFdsgcsTsgjMapper;
import com.zjsgfa.project.zjsgfa.domain.SjFdsgcsTsgj;
import com.zjsgfa.project.zjsgfa.service.ISjFdsgcsTsgjService;

/**
 * 设计-分段施工措施_特殊工具Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-08-06
 */
@Service
public class SjFdsgcsTsgjServiceImpl implements ISjFdsgcsTsgjService 
{
    @Autowired
    private SjFdsgcsTsgjMapper sjFdsgcsTsgjMapper;

    /**
     * 查询设计-分段施工措施_特殊工具
     * 
     * @param id 设计-分段施工措施_特殊工具主键
     * @return 设计-分段施工措施_特殊工具
     */
    @Override
    public SjFdsgcsTsgj selectSjFdsgcsTsgjById(Long id)
    {
        return sjFdsgcsTsgjMapper.selectSjFdsgcsTsgjById(id);
    }

    /**
     * 查询设计-分段施工措施_特殊工具列表
     * 
     * @param sjFdsgcsTsgj 设计-分段施工措施_特殊工具
     * @return 设计-分段施工措施_特殊工具
     */
    @Override
    public List<SjFdsgcsTsgj> selectSjFdsgcsTsgjList(SjFdsgcsTsgj sjFdsgcsTsgj)
    {
        return sjFdsgcsTsgjMapper.selectSjFdsgcsTsgjList(sjFdsgcsTsgj);
    }

    /**
     * 新增设计-分段施工措施_特殊工具
     * 
     * @param sjFdsgcsTsgj 设计-分段施工措施_特殊工具
     * @return 结果
     */
    @Override
    public int insertSjFdsgcsTsgj(SjFdsgcsTsgj sjFdsgcsTsgj)
    {
        return sjFdsgcsTsgjMapper.insertSjFdsgcsTsgj(sjFdsgcsTsgj);
    }

    /**
     * 修改设计-分段施工措施_特殊工具
     * 
     * @param sjFdsgcsTsgj 设计-分段施工措施_特殊工具
     * @return 结果
     */
    @Override
    public int updateSjFdsgcsTsgj(SjFdsgcsTsgj sjFdsgcsTsgj)
    {
        return sjFdsgcsTsgjMapper.updateSjFdsgcsTsgj(sjFdsgcsTsgj);
    }

    /**
     * 批量删除设计-分段施工措施_特殊工具
     * 
     * @param ids 需要删除的设计-分段施工措施_特殊工具主键
     * @return 结果
     */
    @Override
    public int deleteSjFdsgcsTsgjByIds(Long[] ids)
    {
        return sjFdsgcsTsgjMapper.deleteSjFdsgcsTsgjByIds(ids);
    }

    /**
     * 删除设计-分段施工措施_特殊工具信息
     * 
     * @param id 设计-分段施工措施_特殊工具主键
     * @return 结果
     */
    @Override
    public int deleteSjFdsgcsTsgjById(Long id)
    {
        return sjFdsgcsTsgjMapper.deleteSjFdsgcsTsgjById(id);
    }
}
